@@ -37,13 +37,15 @@
  *                MdcMakeImgSwapped()     - Make an endian swapped image   *
  *                MdcGetImgSwapped()      - Get  an endian swapped image   *
  *                MdcUnpackBIT12()        - Unpack 12 bit into Uint16      *
+ *                MdcHashDJB2()           - Get hash using djb2 method     *
+ *                MdcHashSDBM()           - Get hash using sdbm method     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.c,v 1.80 2006/03/17 23:33:44 enlf Exp $ 
+/* $Id: m-algori.c,v 1.83 2007/05/21 20:16:10 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -405,8 +407,9 @@ float MdcSingleImageDuration(FILEINFO *fi, Uint32 frame)
      - make positive 
      - get global & image  variables
  check some parameters 
- Notification: double pixel types may get corrupted quantification values
-               because our quantification is stripped down to a float!!
+
+ WARNING: double pixel types may get corrupted quantification values
+          because our quantification is stripped down to a float!!
 */
 char *MdcImagesPixelFiddle(FILEINFO *fi)
 {
@@ -1860,4 +1863,28 @@ int MdcUnpackBIT12(FILEINFO *fi, Uint32 img)
 
 }
 
+Uint32 MdcHashDJB2(unsigned char *str)
+{
+  Uint32 hash = 5381;
+  int c;
 
+  while ((c = *str++)) {
+    hash = ((hash << 5) + hash) + c; /* hash * 33 + c */
+  }
+
+  return(hash);
+
+}
+
+Uint32 MdcHashSDBM(unsigned char *str)
+{
+  unsigned long hash = 0;
+  int c;
+    
+  while ((c = *str++)) {
+    hash = c + (hash << 6) + (hash << 16) - hash;
+  }
+ 
+  return hash;
+
+}
