@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.h,v 1.17 2006/03/01 23:21:58 enlf Exp $
+/* $Id: m-algori.h,v 1.20 2007/06/21 21:44:35 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -47,6 +47,7 @@
 #define  MdcMakeVAXfl(a)   MdcIEEEfl_to_VAXfl(&a)
 
 #define  MdcmCi2MBq(dose)  (dose * 37.)                    /* mCi -> MBq    */
+#define  MdcMBq2mCi(dose)  (dose / 37.)                    /* MBq -> mCi    */
 
 /****************************************************************************
                             F U N C T I O N S
@@ -84,5 +85,7 @@ Uint8 *MdcMakeImgSwapped(Uint8 *cbuf, FILEINFO *fi, Uint32 img,
                          Uint32 width, Uint32 height, int type);
 Uint8 *MdcGetImgSwapped(FILEINFO *fi, Uint32 img);
 int MdcUnpackBIT12(FILEINFO *fi, Uint32 img);
+Uint32 MdcHashDJB2(unsigned char *str);
+Uint32 MdcHashSDBM(unsigned char *str);
 #endif
 
