@@ -18,7 +18,7 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.178 2007/06/07 21:50:45 enlf Exp $
+/* $Id: m-dicm.c,v 1.180 2007/10/22 19:47:53 enlf Exp $
  */
 
 /*
@@ -2500,7 +2500,14 @@ int mdc_dicom_write_element(FILE *fp, Uint16 group, Uint16 element, Uint32 lengt
   /* write value data */
   if ((ndata != NULL) && (length != 0) && (length != UNDEFINED_LENGTH)) {
     fwrite((Uint8 *)ndata,1,length,fp);
-    if (MAKE_EVEN) fputc('\0',fp);
+    if (MAKE_EVEN) {
+      switch (e->vr) {
+        case UI:
+          fputc('\0',fp); break;
+        default: 
+          fputc(' ',fp);
+      }
+    }
   }
   /* restore original output file endian */
   MDC_FILE_ENDIAN = file_endian_saved;
