@@ -60,7 +60,7 @@
  *                MdcAddCompressionExt()  - Add  compression extension     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.c,v 1.57 2007/05/21 20:16:12 enlf Exp $
+/* $Id: m-fancy.c,v 1.58 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -397,7 +397,7 @@ void MdcGetSafeString(char *dest, char *src, Uint32 length, Uint32 maximum)
    }
 }
 
-int MdcUseDefault(char string[])
+int MdcUseDefault(const char string[])
 {
   /* <enter> = default */
   if (string[0] == '\n' || string[0] == '\r') return(1);
@@ -413,7 +413,7 @@ int MdcPutDefault(char string[]) /* 1=default  or 0=no default */
 
 }
 
-int MdcGetRange(char *item, Uint32 *from, Uint32 *to, Uint32 *step)
+int MdcGetRange(const char *item, Uint32 *from, Uint32 *to, Uint32 *step)
 {
   Uint32 a1, a2, t;
 
@@ -1264,7 +1264,7 @@ int MdcWhichDecompress(void)
   return(MDC_NO);
 }
 
-int MdcWhichCompression(char *fname)
+int MdcWhichCompression(const char *fname)
 {
   char *ext=NULL;
   int compression = MDC_NO;
