@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.h,v 1.30 2007/05/21 20:16:12 enlf Exp $
+/* $Id: m-fancy.h,v 1.31 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -72,9 +72,9 @@ void MdcGetStrLine(char string[], int maxchars, FILE *fp);
 void MdcGetStrInput(char string[], int maxchars);
 int MdcGetSubStr(char *dest, char *src, int dmax, char sep, int n);
 void MdcGetSafeString(char *dest, char *src, Uint32 length, Uint32 maximum);
-int MdcUseDefault(char string[]);
+int MdcUseDefault(const char string[]);
 int MdcPutDefault(char string[]);
-int MdcGetRange(char *item, Uint32 *from, Uint32 *to, Uint32 *step);
+int MdcGetRange(const char *item, Uint32 *from, Uint32 *to, Uint32 *step);
 char *MdcHandleEcatList(char *list, Uint32 **dims, Uint32 max);
 char *MdcHandleNormList(char *list, Uint32 **inrs, Uint32 *it
                                , Uint32 *bt,Uint32 max);
@@ -108,7 +108,7 @@ void MdcWaitForEnter(int page);
 Int32 MdcGetSelectionType(void);
 void MdcFlushInput(void);
 int MdcWhichDecompress(void);
-int MdcWhichCompression(char *fname);
+int MdcWhichCompression(const char *fname);
 void MdcAddCompressionExt(int ctype, char *fname);
 #endif
 
