@@ -47,7 +47,7 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.104 2007/06/20 22:06:36 enlf Exp $ 
+/* $Id: m-files.c,v 1.107 2007/11/09 23:03:50 enlf Exp $ 
  */
 
 /*
@@ -95,7 +95,7 @@
 /****************************************************************************
                             F U N C T I O N S
 ****************************************************************************/
-int MdcOpenFile(FILEINFO *fi, char *path)
+int MdcOpenFile(FILEINFO *fi, const char *path)
 {
   int ctype;
 
@@ -383,9 +383,8 @@ int MdcLoadFile(FILEINFO *fi)
 #endif
 #if MDC_INCLUDE_ECAT
     case MDC_FRMT_ECAT6: msg=MdcReadECAT6(fi); break;
-  #if MDC_INCLUDE_TPC
+
     case MDC_FRMT_ECAT7: msg=MdcReadECAT7(fi); break;
-  #endif
 #endif
 #if MDC_INCLUDE_INTF 
     case MDC_FRMT_INTF: msg=MdcReadINTF(fi); break;
@@ -451,8 +450,9 @@ int MdcSaveFile(FILEINFO *fi, int format, int prefixnr)
 #endif
 #if MDC_INCLUDE_ECAT
     case MDC_FRMT_ECAT6: msg=MdcWriteECAT6(fi); break;
-
+  #if MDC_INCLUDE_TPC
     case MDC_FRMT_ECAT7: msg=MdcWriteECAT7(fi); break;
+  #endif
 #endif
 #if MDC_INCLUDE_INTF
     case MDC_FRMT_INTF : msg=MdcWriteINTF(fi); break;
@@ -562,7 +562,7 @@ int MdcLoadPlane(FILEINFO *fi, Uint32 img)
   return(MDC_OK);
 }
 
-int MdcDecompressFile(char *path)
+int MdcDecompressFile(const char *path)
 {
   char *ext;
 
@@ -634,7 +634,7 @@ int MdcFileSize(FILE *fp)
 
 }
 
-int MdcFileExists(char *fname)
+int MdcFileExists(const char *fname)
 {
 
   FILE *fp;
@@ -647,7 +647,7 @@ int MdcFileExists(char *fname)
 
 }
 
-int MdcKeepFile(char *fname)
+int MdcKeepFile(const char *fname)
 {
   if (MDC_FILE_OVERWRITE == MDC_YES) return(MDC_NO);
 
