@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.h,v 1.28 2007/05/21 20:16:12 enlf Exp $
+/* $Id: m-files.h,v 1.29 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -48,17 +48,17 @@
                             F U N C T I O N S
 ****************************************************************************/
 
-int MdcOpenFile(FILEINFO *fi, char *path);
+int MdcOpenFile(FILEINFO *fi, const char *path);
 int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)());
 int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)());
 int MdcLoadFile(FILEINFO *fi);
 int MdcSaveFile(FILEINFO *fi, int format, int prefixnr);
 int MdcLoadPlane(FILEINFO *fi, Uint32 img);
-int MdcDecompressFile(char *path);
+int MdcDecompressFile(const char *path);
 void MdcStringCopy(char *s1, char *s2, Uint32 length);
 int MdcFileSize(FILE *fp);
-int MdcFileExists(char *fname);
-int MdcKeepFile(char *fname);
+int MdcFileExists(const char *fname);
+int MdcKeepFile(const char *fname);
 int MdcGetFrmt(FILEINFO *fi);
 Uint8 *MdcGetImgBuffer(Uint32 bytes);
 char *MdcHandleTruncated(FILEINFO *fi, Uint32 images, int remap);
