@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.75 2007/06/20 22:06:36 enlf Exp $
+/* $Id: m-global.c,v 1.77 2007/09/20 21:48:18 enlf Exp $
  */
 
 /*
@@ -71,6 +71,26 @@ char *mdc_arg_files[MDC_MAX_FILES];    /* pointers to filenames         */
 int   mdc_arg_convs[MDC_MAX_FRMTS];    /* counter for each conversion   */
 int   mdc_arg_total[2];                /* totals for files & conversion */
 
+/* format support compiled in */
+Int8 FrmtSupported[MDC_MAX_FRMTS] = {
+    0,                  /* MDC_FRMT_NONE  */
+    1,                  /* MDC_FRMT_RAW   */
+    1,                  /* MDC_FRMT_ASCII */
+    MDC_INCLUDE_GIF,    /* MDC_FRMT_GIF   */
+    MDC_INCLUDE_ACR,    /* MDC_FRMT_ACR   */
+    MDC_INCLUDE_INW,    /* MDC_FRMT_INW   */
+    MDC_INCLUDE_ECAT,   /* MDC_FRMT_ECAT6 */
+    MDC_INCLUDE_ECAT,   /* MDC_FRMT_ECAT7 */
+    MDC_INCLUDE_INTF,   /* MDC_FRMT_INTF  */
+    MDC_INCLUDE_ANLZ,   /* MDC_FRMT_ANLZ  */
+    MDC_INCLUDE_DICM,   /* MDC_FRMT_DICM  */
+    MDC_INCLUDE_PNG,    /* MDC_FRMT_PNG   */
+    MDC_INCLUDE_CONC,   /* MDC_FRMT_CONC  */
+    MDC_INCLUDE_NIFTI   /* MDC_FRMT_NIFTI */
+  /*.................                     */
+};
+    
+/* format name */
 char FrmtString[MDC_MAX_FRMTS][15]= {
     "Unknown      ",    /* MDC_FRMT_NONE  */
     "Raw Binary   ",    /* MDC_FRMT_RAW   */
@@ -89,6 +109,7 @@ char FrmtString[MDC_MAX_FRMTS][15]= {
   /*"............."                       */
 };
 
+/* format extension */
 char FrmtExt[MDC_MAX_FRMTS][8] = {
     "???",    /* MDC_FRMT_NONE  */
     "bin",    /* MDC_FRMT_RAW   */
