@@ -17,7 +17,7 @@
  *                the headersize to skip and the pixel data type           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-raw.c,v 1.39 2007/05/21 20:16:14 enlf Exp $
+/* $Id: m-raw.c,v 1.40 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -510,7 +510,7 @@ char *MdcWriteRAW(FILEINFO *fi)
 
 }
 
-int MdcCheckPredef(char *fname)
+int MdcCheckPredef(const char *fname)
 {
   FILE *fp;
   char sig[10];
@@ -524,7 +524,7 @@ int MdcCheckPredef(char *fname)
   return(MDC_YES);
 }
 
-char *MdcReadPredef(char *fname)
+char *MdcReadPredef(const char *fname)
 {
   MdcRawPrevInputStruct *prev = &mdcrawprevinput;
   FILE *fp;
@@ -561,7 +561,7 @@ char *MdcReadPredef(char *fname)
 
 /* write predefined RAW settings, suitable */
 /* as input for interactive read           */
-char *MdcWritePredef(char *fname)
+char *MdcWritePredef(const char *fname)
 {
   FILE *fp;
   MdcRawPrevInputStruct *prev = &mdcrawprevinput;
