@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-raw.h,v 1.10 2007/05/21 20:16:14 enlf Exp $
+/* $Id: m-raw.h,v 1.11 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -64,8 +64,8 @@ extern MdcRawPrevInputStruct mdcrawprevinput;
 void MdcInitRawPrevInput(void);
 char *MdcReadRAW(FILEINFO *fi);
 char *MdcWriteRAW(FILEINFO *fi);
-int MdcCheckPredef(char *fname);
-char *MdcReadPredef(char *fname);
-char *MdcWritePredef(char *fname);
+int MdcCheckPredef(const char *fname);
+char *MdcReadPredef(const char *fname);
+char *MdcWritePredef(const char *fname);
 
 #endif
