@@ -17,11 +17,11 @@
  *                MdcSplitFrames()        - Write each frame to a file     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-split.c,v 1.24 2006/03/01 23:21:59 enlf Exp $
+/* $Id: m-split.c,v 1.26 2007/05/21 20:16:14 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -236,7 +236,7 @@ char *MdcSplitSlices(FILEINFO *fi, int format, int prefixnr)
 {
   FILEINFO *ofi;
   Uint32 nr_of_slices;
-  Int16 instance=0;
+  Int32 instance=0, series=0;
   char *msg, *tpath=NULL, *bname=NULL;
 
   /* alloc temp struct, path */
@@ -253,6 +253,9 @@ char *MdcSplitSlices(FILEINFO *fi, int format, int prefixnr)
     bname = MdcGetSplitBaseName(tpath);
   }
 
+  /* preserve & initialize series number */
+  series = fi->nr_series; fi->nr_series = (Int32)prefixnr + 1;
+
   /* preserve & initialize instance number */
   instance = fi->nr_instance; fi->nr_instance = 0;
 
@@ -261,7 +264,7 @@ char *MdcSplitSlices(FILEINFO *fi, int format, int prefixnr)
   for (mdc_nrsplit=0; mdc_nrsplit < nr_of_slices; mdc_nrsplit++) {
 
      /* increment instance for each slice */
-     fi->nr_instance = (Int16)mdc_nrsplit;
+     fi->nr_instance = (Int32)mdc_nrsplit + 1;
 
      msg = MdcCopySlice(ofi,fi,mdc_nrsplit);
      if (msg != NULL) {
@@ -293,6 +296,9 @@ char *MdcSplitSlices(FILEINFO *fi, int format, int prefixnr)
   MdcFree(ofi);
   MdcFree(tpath);
 
+  /* restore series */
+  fi->nr_series = series;
+
   /* restore instance */
   fi->nr_instance = instance;
 
@@ -303,7 +309,7 @@ char *MdcSplitSlices(FILEINFO *fi, int format, int prefixnr)
 char *MdcSplitFrames(FILEINFO *fi, int format, int prefixnr)
 {
   FILEINFO *ofi;
-  Int16 instance=0;
+  Int32 instance=0, series=0;
   Uint32 i, nr_of_frames=1;
   char *msg, *tpath=NULL, *bname=NULL, *p=NULL;
 
@@ -330,6 +336,9 @@ char *MdcSplitFrames(FILEINFO *fi, int format, int prefixnr)
     }
   }
 
+  /* preserve & initialize series number */
+  series = fi->nr_series; fi->nr_series = (Int32)prefixnr + 1;
+
   /* preserve & initialize instance number */
   instance = fi->nr_instance; fi->nr_instance = 0;
 
@@ -343,7 +352,7 @@ char *MdcSplitFrames(FILEINFO *fi, int format, int prefixnr)
   for (mdc_nrsplit=0; mdc_nrsplit < nr_of_frames; mdc_nrsplit++) {
  
      /* increment instance for each frame */
-     fi->nr_instance = (Int16)mdc_nrsplit;
+     fi->nr_instance = (Int32)mdc_nrsplit + 1;
 
      msg = MdcCopyFrame(ofi,fi,mdc_nrsplit);
      if (msg != NULL) {
@@ -375,6 +384,9 @@ char *MdcSplitFrames(FILEINFO *fi, int format, int prefixnr)
   MdcFree(ofi);
   MdcFree(tpath);
 
+  /* restore series */
+  fi->nr_series = series;
+
   /* restore instance */
   fi->nr_instance = instance;
 
