@@ -37,7 +37,7 @@
  *                MdcCleanUpFI()        - Clean up FILEINFO struct         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.c,v 1.74 2007/06/05 21:01:25 enlf Exp $ 
+/* $Id: m-structs.c,v 1.76 2007/11/19 21:04:03 enlf Exp $ 
  */
 
 /*
@@ -412,7 +412,7 @@ void MdcInitBD(BED_DATA *bd)
 
 }
 
-void MdcInitFI(FILEINFO *fi, char *path)
+void MdcInitFI(FILEINFO *fi, const char *path)
 {  
    fi->ifp = NULL; fi->ifp_raw = NULL; 
    fi->ofp = NULL; fi->ofp_raw = NULL;
@@ -726,12 +726,22 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
     src->ofp = NULL; src->ofp_raw = NULL;
   }
 
+  /* A) src reassemble */
+  MdcMergePath(src->ipath,src->idir,src->ifname);
+  MdcMergePath(src->opath,src->odir,src->ofname);
+
+  /* B) src -> dest */
   memcpy(dest->ipath,src->ipath,MDC_MAX_PATH);
   memcpy(dest->opath,src->opath,MDC_MAX_PATH);
 
+  /* C) dest disassemble */
   MdcSplitPath(dest->ipath,dest->idir,dest->ifname);
   MdcSplitPath(dest->opath,dest->odir,dest->ofname);
 
+  /* D) src disassemble, undo A) */
+  MdcSplitPath(src->ipath,src->idir,src->ifname);
+  MdcSplitPath(src->opath,src->odir,src->ofname);
+
   dest->iformat = src->iformat;
   dest->oformat = src->oformat;
   dest->rawconv = src->rawconv;
