@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.h,v 1.54 2007/06/05 21:01:26 enlf Exp $
+/* $Id: m-structs.h,v 1.55 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -358,7 +358,7 @@ void MdcInitGD(GATED_DATA *gd);
 void MdcInitAD(ACQ_DATA *acq);
 void MdcInitDD(DYNAMIC_DATA *dd);
 void MdcInitBD(BED_DATA *bd);
-void MdcInitFI(FILEINFO *fi, char *path);
+void MdcInitFI(FILEINFO *fi, const char *path);
 char *MdcCopyMOD(MOD_INFO *mod, MOD_INFO *src);
 char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE);
 char *MdcCopySD(STATIC_DATA *dest, STATIC_DATA *src);
