@@ -20,7 +20,7 @@
  *                XMdcColGbcCorrectSel();         - GBC selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolgbc.c,v 1.17 2007/05/21 20:16:15 enlf Exp $
+/* $Id: xcolgbc.c,v 1.19 2007/11/14 23:09:43 enlf Exp $
  */
 
 /*
@@ -173,9 +173,13 @@ void XMdcColGbcCorrectModValue(GtkWidget *widget, SliderValueStruct *v)
 void XMdcColGbcCorrectResetValue(GtkWidget *widget, SliderValueStruct *v)
 {
   (*(v->value)) = 255;
+#ifdef GTKONE
   GTK_ADJUSTMENT(v->adj)->value = (gfloat)(*(v->value));
   gtk_range_set_adjustment(GTK_RANGE(v->range), GTK_ADJUSTMENT(v->adj));
   gtk_range_slider_update(GTK_RANGE(v->range));
+#else
+  gtk_range_set_value(GTK_RANGE(v->range), (gfloat)(*(v->value)));
+#endif
   XMdcColGbcCorrectUpdate();
 }
 
