@@ -23,7 +23,7 @@
  *                                                                         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolmap.c,v 1.28 2007/05/21 20:16:16 enlf Exp $
+/* $Id: xcolmap.c,v 1.29 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -541,7 +541,7 @@ void XMdcBuildColorMap(void)
 
 }
 
-int XMdcLoadLUT(gchar *lutname)
+int XMdcLoadLUT(const gchar *lutname)
 {
   if (MdcLoadLUT(lutname) == MDC_YES) {
 
