@@ -19,7 +19,7 @@
  *                XMdcShowErrorConsole() - Show the error console          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xerror.c,v 1.20 2007/05/21 20:16:16 enlf Exp $
+/* $Id: xerror.c,v 1.21 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -43,6 +43,9 @@
                               H E A D E R S
 ****************************************************************************/
 
+/* gtktext was replaced by gtktextview in gtk-2.0, this enables it in 2.0 */
+#define GTK_ENABLE_BROKEN
+
 #include <stdio.h>
 #include <time.h>
 #include <gtk/gtk.h>
