@@ -17,7 +17,7 @@
  *                XMdcExtractStyleSel()               - Extract Style Sel  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xextract.c,v 1.23 2007/05/21 20:16:16 enlf Exp $
+/* $Id: xextract.c,v 1.25 2007/11/14 23:09:43 enlf Exp $
  */
 
 /*
@@ -135,14 +135,16 @@ void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data)
       return;
     }
 
-    entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputPlanes));
+    entry = g_strdup(gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputPlanes)));
     
     it = 1; bt = 2;
     if (XMdcHandleNormList(entry,&input->inrs,&it,&bt,my.fi->number) 
          != MDC_YES) {
       MdcFree(input->inrs);
       return;
+      g_free(entry);
     } 
+    g_free(entry);
 
   }else{
     if ( (planes=(Uint32 *)malloc((my.fi->dim[3]+1)*sizeof(Uint32)))==NULL ) {
@@ -169,29 +171,37 @@ void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data)
     }
     memset(beds,0,(my.fi->dim[6]+1)*sizeof(Uint32));
 
-    entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputPlanes));
+    entry = g_strdup(gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputPlanes)));
     if (XMdcHandleEcatList(entry,&planes,(unsigned)my.fi->dim[3]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
+      g_free(entry);
       return;
     }
+    g_free(entry);
 
-    entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputFrames));
+    entry = g_strdup(gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputFrames)));
     if (XMdcHandleEcatList(entry,&frames,(unsigned)my.fi->dim[4]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
+      g_free(entry);
       return;
     }
+    g_free(entry);
 
-    entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputGates));
+    entry = g_strdup(gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputGates)));
     if (XMdcHandleEcatList(entry,&gates,(unsigned)my.fi->dim[5]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
+      g_free(entry);
       return;
     }
+    g_free(entry);
 
-    entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputBeds));
+    entry = g_strdup(gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputBeds)));
     if (XMdcHandleEcatList(entry,&beds,(unsigned)my.fi->dim[6]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
+      g_free(entry);
       return;
     }
+    g_free(entry);
 
     MdcDebugPrint("p=%u f=%u g=%u b=%u",planes[0],frames[0],gates[0],beds[0]); 
 
@@ -325,7 +335,9 @@ void XMdcGetImages(void)
      gtk_entry_set_text(GTK_ENTRY(planes),"0");
      gtk_editable_select_region(GTK_EDITABLE(planes),0,-1);
      gtk_box_pack_start(GTK_BOX(box3),planes,TRUE,TRUE,0);
+#ifdef GTKONE
      gtk_widget_draw_default(planes);
+#endif
      gtk_widget_show(planes);
      sExtractSelection.InputPlanes=planes;
 
