@@ -13,7 +13,7 @@
  *                XMdcNoFileOpened()       - Give message if no file open  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfiles.c,v 1.14 2007/05/21 20:16:17 enlf Exp $
+/* $Id: xfiles.c,v 1.15 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -55,7 +55,7 @@
                             F U N C T I O N S
 ****************************************************************************/
 
-void XMdcDisplayFile(char *fname)
+void XMdcDisplayFile(const char *fname)
 {
   XMdcViewerHide();
   XMdcMainWidgetsInsensitive();
