@@ -26,7 +26,7 @@
  *                XMdcRawPredefSelOpen()            - Raw Predef Load      * 
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfilesel.c,v 1.32 2007/06/20 22:06:36 enlf Exp $
+/* $Id: xfilesel.c,v 1.33 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -81,7 +81,7 @@ static GtkWidget *default_name=NULL;
 /* Get the selected filename and display */
 void XMdcFileSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs)
 {
-    char *fname;
+    const char *fname;
 
     if (OPEN_TYPE == XMDC_RAW) {
 
@@ -546,7 +546,7 @@ void XMdcFileSelSave(GtkWidget *widget, guint format)
 
 void XMdcLutSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs)
 {
-   char *fname;
+   const char *fname;
 
    fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 
@@ -601,7 +601,8 @@ void XMdcLutSelOpen(GtkWidget *widget, gpointer data)
 
 void XMdcRawPredefSelSaveCallbackOk(GtkWidget *widget, GtkWidget *fs)
 {
-  gchar *fname, *msg;
+  const gchar *fname;
+  gchar *msg;
 
   fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 
@@ -660,7 +661,8 @@ void XMdcRawPredefSelSave(GtkWidget *widget, gpointer data)
 
 void XMdcRawPredefSelOpenCallbackOk(GtkWidget *w, GtkWidget *fs)
 {
-   char *fname, *msg;
+   const gchar *fname;
+   char *msg;
 
    fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 
