@@ -18,7 +18,7 @@
  *                XMdcLabelSel()                - Label selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xlabels.c,v 1.20 2007/05/21 20:16:18 enlf Exp $
+/* $Id: xlabels.c,v 1.22 2007/11/14 23:09:43 enlf Exp $
  */
 
 /*
@@ -304,8 +304,13 @@ void XMdcLabelSel(void)
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurState == MDC_YES) 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+#ifdef GTKONE
     gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                        GTK_SIGNAL_FUNC(XMdcSensitiveColNumFrames),NULL);
+#else
+    gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                       GTK_SIGNAL_FUNC(XMdcSensitiveColNumFrames),NULL);
+#endif
     gtk_widget_show(button);
     sLabelSelection.On = button;
 
@@ -314,8 +319,13 @@ void XMdcLabelSel(void)
     gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
     if (sLabelSelection.CurState == MDC_NO)
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+#ifdef GTKONE
     gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                        GTK_SIGNAL_FUNC(XMdcUnsensitiveColNumFrames),NULL);
+#else
+    gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                       GTK_SIGNAL_FUNC(XMdcUnsensitiveColNumFrames),NULL);
+#endif
     gtk_widget_show(button);
     sLabelSelection.Off = button;
     /* create label colors frame */
