@@ -29,7 +29,7 @@
  *                XMdcInitCineButtons()            - Init cine buttons     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xoptions.c,v 1.67 2007/06/20 22:01:58 enlf Exp $
+/* $Id: xoptions.c,v 1.69 2007/11/14 23:09:43 enlf Exp $
  */
 
 /*
@@ -441,8 +441,13 @@ void XMdcOptionsMedconAddTabPixels(GtkWidget *notebook)
   gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
   if (MDC_FORCE_INT == MDC_NO)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+#ifdef GTKONE
   gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcUnsensitiveBitsUsed12),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                     GTK_SIGNAL_FUNC(XMdcUnsensitiveBitsUsed12),NULL);
+#endif
   gtk_widget_show(button);
   sOptionsMedCon.PixTypeNONE = button;
 
@@ -451,8 +456,13 @@ void XMdcOptionsMedconAddTabPixels(GtkWidget *notebook)
   gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
   if (MDC_FORCE_INT == BIT8_U)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+#ifdef GTKONE
   gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcUnsensitiveBitsUsed12),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                     GTK_SIGNAL_FUNC(XMdcUnsensitiveBitsUsed12),NULL);
+#endif
   gtk_widget_show(button);
   sOptionsMedCon.PixTypeBIT8_U = button;
 
@@ -466,8 +476,13 @@ void XMdcOptionsMedconAddTabPixels(GtkWidget *notebook)
   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
   if (MDC_FORCE_INT == BIT16_S)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+#ifdef GTKONE
   gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcSensitiveBitsUsed12),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                     GTK_SIGNAL_FUNC(XMdcSensitiveBitsUsed12),NULL);
+#endif
   gtk_widget_show(button);
   sOptionsMedCon.PixTypeBIT16_S = button;
 
@@ -753,8 +768,13 @@ void XMdcOptionsMedconAddTabSlices(GtkWidget *notebook)
 
   button = gtk_check_button_new_with_label("[r]  cine sorting:");
   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+#ifdef GTKONE
   gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcToggleSensitivityCine),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                     GTK_SIGNAL_FUNC(XMdcToggleSensitivityCine),NULL);
+#endif
   gtk_widget_show(button);
   sOptionsMedCon.SortCine = button;
 
@@ -1111,8 +1131,13 @@ in the tab Formats\n\n\
 
   button = gtk_check_button_new_with_label("[r]  enable mosaic support");
   gtk_box_pack_start(GTK_BOX(box3),button,FALSE,FALSE,0);
+#ifdef GTKONE
   gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcToggleSensitivityMosaic),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                     GTK_SIGNAL_FUNC(XMdcToggleSensitivityMosaic),NULL);
+#endif
   if (MDC_DICOM_MOSAIC_ENABLED == MDC_YES)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
   gtk_widget_show(button);
@@ -1125,8 +1150,13 @@ in the tab Formats\n\n\
 
   button = gtk_check_button_new_with_label("[r]  force specified stamps layout");
   gtk_box_pack_start(GTK_BOX(box4),button,FALSE,FALSE,5);
+#ifdef GTKONE
   gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcToggleSensitivityForced),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(button),"toggled",
+                     GTK_SIGNAL_FUNC(XMdcToggleSensitivityForced),NULL);
+#endif
   if (MDC_DICOM_MOSAIC_FORCED == MDC_YES)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
   gtk_widget_show(button);
@@ -1148,8 +1178,10 @@ in the tab Formats\n\n\
   adj=(GtkAdjustment *)gtk_adjustment_new(0., 0., 9999., 1., 4., 0.);
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
+#ifdef GTKONE
   gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner),
                                   GTK_SHADOW_ETCHED_IN);
+#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_table_attach_defaults(GTK_TABLE(table2),spinner,1,2,0,1);
@@ -1172,8 +1204,10 @@ in the tab Formats\n\n\
   adj=(GtkAdjustment *)gtk_adjustment_new(0., 0., 9999., 1., 4., 0.);
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
+#ifdef GTKONE
   gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner),
                                   GTK_SHADOW_ETCHED_IN);
+#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_table_attach_defaults(GTK_TABLE(table2),spinner,1,2,1,2);
@@ -1196,8 +1230,10 @@ in the tab Formats\n\n\
   adj=(GtkAdjustment *)gtk_adjustment_new(0., 0., 9999., 1., 4., 0.);
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
+#ifdef GTKONE
   gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner),
                                   GTK_SHADOW_ETCHED_IN);
+#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_table_attach_defaults(GTK_TABLE(table2),spinner,1,2,2,3);
@@ -1683,20 +1719,30 @@ void XMdcUnsensitiveBitsUsed12(GtkWidget *widget, gpointer data)
 
 void XMdcToggleSensitivityMosaic(GtkWidget *widget, gpointer data)
 {
+#ifdef GTKONE
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.DicmMosaicEnabled)->active) {
     gtk_widget_set_sensitive(GTK_WIDGET(wmosaic),FALSE);
   }else{
     gtk_widget_set_sensitive(GTK_WIDGET(wmosaic),TRUE);
   }
+#else
+  gtk_widget_set_sensitive(GTK_WIDGET(wmosaic), 
+  			   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+#endif
 }
 
 void XMdcToggleSensitivityForced(GtkWidget *widget, gpointer data)
 {
+#ifdef GTKONE
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.DicmMosaicForced)->active) {
     gtk_widget_set_sensitive(GTK_WIDGET(wforced),FALSE);
   }else{
     gtk_widget_set_sensitive(GTK_WIDGET(wforced),TRUE);
   }
+#else
+    gtk_widget_set_sensitive(GTK_WIDGET(wforced),
+  			   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+#endif
 }
 
 void XMdcInitMosaicFrame(void)
@@ -1736,6 +1782,7 @@ void XMdcInitMosaicFrame(void)
 
 void XMdcToggleSensitivityCine(GtkWidget *widget, gpointer data)
 { 
+#ifdef GTKONE
    if (GTK_TOGGLE_BUTTON(sOptionsMedCon.SortCine)->active) {
      gtk_widget_set_sensitive(GTK_WIDGET(sOptionsMedCon.SortCineApply),FALSE);
      gtk_widget_set_sensitive(GTK_WIDGET(sOptionsMedCon.SortCineUndo),FALSE); 
@@ -1743,6 +1790,12 @@ void XMdcToggleSensitivityCine(GtkWidget *widget, gpointer data)
      gtk_widget_set_sensitive(GTK_WIDGET(sOptionsMedCon.SortCineApply),TRUE);
      gtk_widget_set_sensitive(GTK_WIDGET(sOptionsMedCon.SortCineUndo),TRUE);
    }
+#else
+     gtk_widget_set_sensitive(GTK_WIDGET(sOptionsMedCon.SortCineApply),
+			      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+     gtk_widget_set_sensitive(GTK_WIDGET(sOptionsMedCon.SortCineUndo),
+			      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+#endif
 }
 
 void XMdcInitCineButtons(void)
