@@ -20,7 +20,7 @@
  *                XMdcGetHeaderInfo()             - Ask Hdr Info           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreader.c,v 1.24 2007/05/21 20:16:19 enlf Exp $
+/* $Id: xreader.c,v 1.25 2007/11/09 23:03:50 enlf Exp $
  */
 
 /*
@@ -74,7 +74,7 @@ static MdcRawPrevInputStruct *prev = &mdcrawprevinput;
                             F U N C T I O N S
 ****************************************************************************/
 
-int XMdcReadFile(char *fname)
+int XMdcReadFile(const char *fname)
 {
 
   if (MdcOpenFile(my.fi,fname) != MDC_OK) {
@@ -152,7 +152,7 @@ void XMdcRawReadFinish(guint otype)
 
 void XMdcRawReadInteractive(GtkWidget *fs)
 {
-  char *fname;
+  const char *fname;
 
   XMdcMainWidgetsInsensitive();
 
@@ -173,7 +173,7 @@ void XMdcRawReadPredef(GtkWidget *fs)
 {
   IMG_DATA *id;
   Uint32 i;
-  char *fname;
+  const char *fname;
 
   XMdcMainWidgetsInsensitive();
 
@@ -284,7 +284,7 @@ Int16 XMdcGetImageInfoPixelType(void)
 void XMdcGetImageInfoCallbackApply(void)
 {
   IMG_DATA *id=NULL;
-  char *entry;
+  const char *entry;
   Uint32 i, width, height, offset, imgnr;
   Int16 type;
 
@@ -622,7 +622,7 @@ void XMdcGetImageInfo(void)
 void XMdcGetHeaderInfoCallbackApply(void)
 {
   Uint32 number;
-  char *entry = NULL;
+  const char *entry = NULL;
 
   /* total number of images */
   entry = gtk_entry_get_text(GTK_ENTRY(raw->NrImages));
