@@ -16,7 +16,7 @@
  *                XMdcViewerDisableAutoShrink()- Disable auto shrinking    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xviewer.c,v 1.25 2007/05/21 20:16:20 enlf Exp $
+/* $Id: xviewer.c,v 1.27 2007/11/14 23:09:43 enlf Exp $
  */
 
 /*
@@ -350,13 +350,13 @@ void XMdcBuildViewerWindow(void)
   gtk_widget_show(my.pagemenu);
 
   button = gtk_button_new_with_label("Next");
-  gtk_signal_connect(GTK_OBJECT(button),"clicked",
+  gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcPagesNext),NULL);
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,0);
   gtk_widget_show(button);
 
   button = gtk_button_new_with_label("Prev");
-  gtk_signal_connect(GTK_OBJECT(button),"clicked",
+  gtk_signal_connect(GTK_OBJECT(button),"button-release-event",
                      GTK_SIGNAL_FUNC(XMdcPagesPrev),NULL);
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,0);
   gtk_widget_show(button);
@@ -432,17 +432,24 @@ void XMdcBuildViewerWindow(void)
 
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
+#ifdef GTKONE
   gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner),
                                   GTK_SHADOW_ETCHED_IN);
+#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
 
   gtk_box_pack_start(GTK_BOX(entrybox),spinner,FALSE,FALSE,5);
 
+#ifdef GTKONE
   gtk_signal_connect_after(GTK_OBJECT(spinner),"key_press_event",
                      GTK_SIGNAL_FUNC(XMdcPagesGoTo),NULL);
   gtk_signal_connect_after(GTK_OBJECT(spinner), "button_release_event",
                            GTK_SIGNAL_FUNC(XMdcPagesGoTo),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(spinner),"value_changed",
+                     GTK_SIGNAL_FUNC(XMdcPagesGoTo),NULL);
+#endif
   gtk_widget_show(spinner);
 
   label = gtk_label_new("Table: ");
@@ -456,17 +463,24 @@ void XMdcBuildViewerWindow(void)
 
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
+#ifdef GTKONE
   gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spinner), 
                                   GTK_SHADOW_ETCHED_IN);
+#endif
   gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spinner), TRUE);
   gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(spinner), TRUE);
 
   gtk_box_pack_start(GTK_BOX(entrybox),spinner,FALSE,FALSE,5);
 
+#ifdef GTKONE
   gtk_signal_connect_after(GTK_OBJECT(spinner),"key_press_event",
                      GTK_SIGNAL_FUNC(XMdcChangeLUT),NULL);
   gtk_signal_connect_after(GTK_OBJECT(spinner), "button_release_event",
                            GTK_SIGNAL_FUNC(XMdcChangeLUT),NULL);
+#else
+  gtk_signal_connect(GTK_OBJECT(spinner),"value_changed",
+                     GTK_SIGNAL_FUNC(XMdcChangeLUT),NULL);
+#endif
   gtk_widget_show(spinner);
 
   box2 = gtk_hbox_new(FALSE, 2);
