@@ -11,7 +11,7 @@
  *                XMdcEditFileInfo()            - Edit FILEINFO struct     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xvifi.c,v 1.27 2007/05/21 20:16:20 enlf Exp $
+/* $Id: xvifi.c,v 1.29 2007/11/14 23:09:43 enlf Exp $
  */
 
 /*
@@ -66,7 +66,8 @@ void XMdcEditFileInfoCallbackApply(GtkWidget *widget, gpointer data)
   
   IMG_DATA *id;
   DYNAMIC_DATA *dd;
-  char *entry, *msg;
+  const char *entry;
+  char *msg;
   float pixel_size, slice_width, slice_spacing, frame_duration;
   Uint32 i, planes, frames, gates, beds, windows, number;
 
@@ -363,7 +364,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr); 
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->PixelSize = entry;
 
@@ -384,7 +387,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr); 
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,1,2);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->SliceWidth = entry;
 
@@ -405,7 +410,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,2,3);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->SliceSpacing = entry;
 
@@ -431,7 +438,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,3,4);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->FrameDuration = entry;
 
@@ -477,7 +486,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,0,1);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->NrDimPlanes = entry;
 
@@ -498,7 +509,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,1,2);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->NrDimFrames = entry;
 
@@ -519,7 +532,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,2,3);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->NrDimGates = entry;
 
@@ -540,7 +555,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,3,4);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->NrDimBeds = entry;
 
@@ -561,7 +578,9 @@ void XMdcEditFileInfo(void)
    gtk_entry_set_text(GTK_ENTRY(entry),mdcbufr);
    gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
    gtk_table_attach_defaults(GTK_TABLE(table),entry,1,2,4,5);
+#ifdef GTKONE
    gtk_widget_draw_default(entry);
+#endif
    gtk_widget_show(entry);
    vifi->NrDimWindows = entry;
 
